Supported Browsers — Pootle 2.7.6 documentation

# Supported Browsers

Pootle targets the latest stable versions of major modern web browsers.

Pootle should not only work correctly, but it should also look great in Firefox, Chrome and Safari.

Internet Explorer is an exception, where we support the latest two stable versions (as of today, IE11+). Here Pootle should work well, but might look imperfect.

Older browser versions might work properly too, but we are not committed to ensure such support.

A nice to have goal is making Pootle usable in smaller screens such as iPads. But this is not a hard requirement.

If you are about to use a feature which might not be available in the set of supported browsers, check the Can I Use... website first.